<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_MX">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraSettingsDialog</name>
    <message>
        <source>Camera settings</source>
        <translation>Configuración de la cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Remover el marco de la ventana</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Distribuir en dos ventanas verticales</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Distribuir en dos ventanas horizontales</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Tonos de Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y Negro</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a Ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Cambiar a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a Ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Cambiar a pantalla completa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>La instalación fue correcta.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Cierra la ventana e inicia vokoscreenNG de nuevo.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Diviértete con vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elige uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró el manejador de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un manejador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La grabación no ha comenzado porque no hay suficiente espacio libre en el disco. </translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>El espacio libre del disco se agotó. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Espacio libre del disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La grabación se detuvo porque no hay espacio libre en el disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>No se encontró el manejador de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un manejador de archivos.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página de inicio</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página de inicio</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elige uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró el manejador de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale un manejador de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Distribuir en dos ventanas horizontales</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Distribuir en dos ventanas verticales</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Tonos de Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y Negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover el marco de la ventana</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configuración de la cámara</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Redefinir</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño del video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio libre del disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cuadros</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de audio</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el cursor del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar el cronómetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Detener la grabación después de </translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta al video</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Espacio libre del disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundos a esperar antes de la grabación</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Tonos de Gris</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+MAYUS+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+MAYUS+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+MAYUS+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir la última grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+MAYUS+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizada cuando comience la grabación</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Comienza minimizada</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Distribuir en dos ventanas horizontales</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Distribuir en dos ventanas verticales</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y Negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover el marco de la ventana</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Redefinir la configuración en la siguiente grabación</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia sobre la grabación</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Pantalla de grabación</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Bitácora</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automáticamente</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Crear imágenes de tabuladores</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Información de Licencia</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Accesos directos globales de teclado</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Teclas de acceso directo asignadas.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Acceso directo de teclado no asignado más de una vez.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Si esto se muestra como asignado, pero no funciona, está siendo utilizado por otro programa.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Ruta de la imagen</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Oculta esta ventana</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Segundos de espera antes de grabar</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla Completa</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia sobre la grabación</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Crear imágenes de tabuladores</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Información de Licencia</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño del video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio libre del disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla Completa</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cuadros</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el cursor del ratón</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia sobre la grabación</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
</context>
</TS>